==> pubsub.io-0.1.0.tgz: package/README.md <==
# Pubsub.io JS client
**a query based client/server publish subscribe protocol built on node.js.**

Client implementions for the browser and node.js.

```js
// to connect in node.js do:
var pubsub = require('pubsub').connect('www.pubsub.io');

// to connect in the browser do:
var pubsub = pubsub.connect('www.pubsub.io');

pubsub.subscribe({}, function(doc) {
	console.log('someone published', doc);
});

pubsub.publish({foo:'bar'});
```

# LICENSE

Copyright (c) 2011 Ian Jørgensen <i@pubsub.io> and Mathias Buus Madsen <mathiasbuus@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

==> pubsub.io-0.1.3.tgz: package/README.md <==
# Pubsub.io JS client
**a query based client/server publish subscribe protocol built on node.js.**

Client implementions for the browser and node.js.

```js
// to connect in node.js do:
var pubsub = require('pubsub.io').connect('hub.pubsub.io');

// to connect in the browser do:
var pubsub = pubsub.connect('hub.pubsub.io');

pubsub.subscribe({}, function(doc) {
	console.log('someone published', doc);
});

pubsub.publish({foo:'bar'});
```

# LICENSE

Copyright (c) 2011 Ian Jørgensen <i@pubsub.io> and Mathias Buus Madsen <mathiasbuus@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.
